/*Substance Painter Export Masks
#Version: 1.0.0
#Update: 
#Description: Substance Painter plugin for exporting masks from selected layers

#Contact: wes.mcdermott@allegorithmic.com
*/

//Note: you only need '.pragma library' if you are planning to
//change this variable from multiple qml files
.pragma library

var res = "Document Resolution";
var dir = "";
var format = "png";


var selectedLayers = [];
var selectedLayerNames = [];

//Log to console
function log(msg, mode) {
    
    switch(mode) {
     case "info":
        alg.log.info(msg);
      break;
     case "warn":
        alg.log.warn(msg);
        break;
     case "error":
        alg.log.error(msg);    
        break;
     }
}

function addSelectedLayer(path, channel) {
    var layerPath = path.slice(0);
	layerPath.push(channel);
	selectedLayers.push(layerPath);
}

function checkLayers(path, layer) {
    
    //dataPath ["material name", "Layer Group", "Layer 1", "mask"]
    path.push(layer.name); //add layer name to path array [material.name, stack.name, layer.name]
   
    // layer or layer group in the stack that has a mask
    if (layer.hasMask && (layer.selected || layer.maskSelected)) {
	   
       //send the path and mask flag
       addSelectedLayer(path, "mask");  
       
       selectedLayerNames.push(layer.name);//add layer name to array
    } 
    
    //loop through any layer groups and repeat process
    for (var l in layer.layers) {
	 
       checkLayers(path, layer.layers[l]);
      
    }
    
    path.pop(); //remove items as they are exported
  
}

//Eport selected layer masks
function exportMasks() {
  
 if(res == null) res = "Document Resolution";
 if(format == null) format="png";
  
   try {
     
     selectedLayers.length = 0;//clear the array
     selectedLayerNames.length = 0;//clear the array
     
     var structure = alg.mapexport.documentStructure(); //document structure - texture set and layer stack
     
     //texture sets 
     for (var m in structure.materials) {
		var material = structure.materials[m]; 
        
        //layer stack
        for (var s in material.stacks) {
		  
          var stack = material.stacks[s];
         
          //layers in the stack
          for (var l in stack.layers) {

           //all layers in the stack - stack.layers[l]
           checkLayers([material.name, stack.name], stack.layers[l]);
            
		   }
        }      
     }
     
     //eport masks
     for(var i in selectedLayers) {
       
       
       if(res == "Document Resolution") {
           
           alg.mapexport.save(selectedLayers[i], dir+"/" + selectedLayerNames[i]+"_mask" + "."+format, {padding:false});
           
           
       }else{
           
           alg.mapexport.save(selectedLayers[i], dir+"/" + selectedLayerNames[i]+"_mask" + "."+format, {padding:false, resolution:[Number(res), Number(res)]});
           
       }
	}
       
   } catch (error) {
       
       log(error, "error");
   }
}



